/// <reference types="react" />
import { JSXElementConstructor } from "react";
/**
 * This object represents an event that is supplied by the client
 */
interface CalendarEvent {
    /** Unique *external* ID of the event */
    id: string;
    /** Start date of the event (ISO format w/Timezone) */
    start: string;
    /** End date of the event  (ISO format w/Timezone) */
    end: string;
    /** Text that will be visible on the event */
    summary: string;
    /** Visible color of the event *(css color value)* */
    color: string;
}
/**
 * This object represents an event that is displayed on the calendar
 */
interface InternalCalendarEvent {
    /** Unique *external* ID of the event */
    id: string;
    /** Start date of the event */
    start: Date;
    /** End date of the event */
    end: Date;
    /** Text that will be visible on the event */
    summary: string;
    /** Visible color of the event *(css color value)* */
    color: string;
}
/** Represents the state of the ActionProvider */
interface ActionState {
    /** function that will run when an event is clicked on */
    onEventClick: (event: InternalCalendarEvent) => void;
    /** function that will run when the 'more events' indicator is clicked on */
    onMoreEventClick: (event: InternalCalendarEvent[]) => void;
}
interface InternalEventWeek {
    weekStart: Date;
    weekEnd: Date;
    daysInWeek: Date[];
    events: InternalCalendarEvent[];
    eventsOnDays: {
        date: Date;
        events: InternalCalendarEvent[];
    }[];
}
type CalendarState = {
    /** The current visible month */
    currentMonth: Date;
    /** The DateTimeAdapter that is being utilized */
    dateAdapter: DateTimeAdapter;
    /** Array with localized names of the days of the week */
    daysOfWeek: string[];
    /** Advance the calendar one month */
    onNextMonth: () => void;
    /** Decrease the calendar by one month */
    onPrevMonth: () => void;
    /** Calendar with events that will be displayed */
    calendarWithEvents: InternalEventWeek[];
};
/**
 * Common interface for porting date libraries so they can be used with Schedulely
 */
interface DateTimeAdapter {
    /** Add the specified number of months to the date. Using a negative value will subtract that amount. */
    addMonthsToDate: (date: Date, amount: number) => Date;
    /** Returns all days in the month, split apart by week. Includes leading/trailing days. */
    getCalendarView: (date: Date) => Date[][];
    /** Get the day number component for a given date */
    getDayNumber: (date: Date) => number;
    /** Get full names of all days of the week */
    getDaysOfWeek: (displaySize: DisplaySize) => string[];
    /** Get the day of week grid index for the end of the event. Used for positioning within the Week css-grid. */
    getGridEndIndex: (eventEndDate: Date, endOfWeek: Date) => number;
    /** Get the day of week index for the start of the event. Used for positioning within the Week css-grid */
    getGridStartIndex: (eventDate: Date, startOfWeek: Date) => number;
    /** Get the full name of the month for a given date */
    getMonthName: (date: Date) => string;
    /** Get the year component for a given date */
    getYear: (date: Date) => number;
    /** Convert and ISO format string to a Date object */
    convertIsoToDate: (isoDate: string) => Date;
    /** Returns true if the date represent today */
    isDateToday: (date: Date) => boolean;
    /** Does the event fall within or span the supplied week */
    isEventInWeek: (eventStartDate: Date, eventEndDate: Date, week: Date[]) => boolean;
    /** Compare two dates, returns true if they are in the same month, in the same year */
    isSameMonth: (firstDate: Date, secondDate: Date) => boolean;
}
declare enum DisplaySize {
    tiny = 0,
    medium = 1,
    large = 2
}
interface HighlightEventState {
    /** Set the ID of the currently highlighted event */
    setHighlight: (eventId: string) => void;
    /** Clear the currently value for highlightedEvent */
    clearHighlight: () => void;
    /** Check if the eventId equals the currently highlighted event */
    isHighlighted: (eventId: string) => boolean;
}
/**
 * Props interface for More Events Indicator components
 */
interface MoreEventsIndicatorProps {
    events: InternalCalendarEvent[];
    /** Function executes when the indicator is clicked */
    onClick: (event: InternalCalendarEvent[]) => void;
}
/**
 * Type used for creating MoreEventsIndicatorComponent
 */
type MoreEventsIndicatorComponent = JSXElementConstructor<MoreEventsIndicatorProps>;
interface SchedulelyComponents {
    dayOfWeekComponent: DayOfWeekComponent;
    dayComponent: DayComponent;
    forwardNavigationButtonComponent: NavigationButtonComponent;
    backwardNavigationButtonComponent: NavigationButtonComponent;
    headerBannerComponent: HeaderBannerComponent;
    dayHeaderComponent: DayHeaderComponent;
    eventComponent: EventComponent;
    moreEventsIndicatorComponent: MoreEventsIndicatorComponent;
}
/**
 * Props interface for creating Day components
 */
interface DayComponentProps {
    /** Does this date represent the current month (used for coloring trailing/leading days) */
    isCurrentMonth: boolean;
    /** Child elements within the day */
    children?: JSX.Element | JSX.Element[];
}
/**
 * Type used for creating DayComponent
 */
type DayComponent = JSXElementConstructor<DayComponentProps>;
/**
 * Props interface for creating Day components
 */
interface DayHeaderComponentProps {
    /** The day number portion of the Date */
    dateNumber: number;
    /** Does this date represent today? */
    isToday: boolean;
}
/**
 * Type used for creating DayComponent
 */
type DayHeaderComponent = JSXElementConstructor<DayHeaderComponentProps>;
/** Props used when creating a DayOfWeek */
interface DayOfWeekProps {
    /** The the name of the day */
    dayName: string;
}
/** Displays the name of the day at the top of the calendar column */
type DayOfWeekComponent = JSXElementConstructor<DayOfWeekProps>;
/**
 * Props interface for creating Event components
 */
interface EventComponentProps {
    /* The object that represents this event */
    event: InternalCalendarEvent;
    /* True when event is hovered. Can be used to control event display when spanning multiple weeks. */
    isHovered: boolean;
    /** Function executes when the event is clicked */
    onClick: (event: InternalCalendarEvent) => void;
}
/**
 * Type used for creating EventComponent
 */
type EventComponent = JSXElementConstructor<EventComponentProps>;
/** Props used when creating a HeaderBanner */
interface HeaderBannerProps {
    /** The current month the calendar is displaying */
    month: string;
    /** The current year the calendar is displaying */
    year: number;
}
/** The month/year banner displayed at the top of the calendar */
type HeaderBannerComponent = JSXElementConstructor<HeaderBannerProps>;
/** Props used when creating a NavigationButton */
interface NavigationButtonComponentProps {
    /** Action taken when button is clicked */
    onClick: () => void;
    children?: JSX.Element | JSX.Element[];
}
/** Button used for forward/backward navigation of months */
type NavigationButtonComponent = JSXElementConstructor<NavigationButtonComponentProps>;
/** Properties used to initialize Schedulely */
interface SchedulelyProps {
    /** DateAdapter used to process dates */
    dateAdapter?: DateTimeAdapter;
    /** Component overrides */
    schedulelyComponents?: Partial<SchedulelyComponents>;
    /** List of events to display */
    events: CalendarEvent[];
    /** Additional class names to apply to the root div */
    additionalClassNames?: string[];
    /** Name of theme to display */
    theme?: string;
    actions?: Partial<ActionState>;
}
/**
 * Create an instance of Schedulely
 * @param {SchedulelyProps} param0 Schedulely configuration properties
 * @returns
 */
declare const Schedulely: ({ dateAdapter, schedulelyComponents, events, theme, additionalClassNames, actions }: SchedulelyProps) => JSX.Element;
/* eslint-disable @typescript-eslint/no-explicit-any */
/**
 * Shim type to avoid import date-fns
 * Could be brittle if they change type
 */
interface Interval {
    start: number | Date;
    end: number | Date;
}
/**
 * Shim type to avoid import date-fns
 * Could be brittle if they change type
 */
interface Locale {
    code?: string;
    formatDistance?: (...args: Array<any>) => any;
    formatRelative?: (...args: Array<any>) => any;
    localize?: {
        ordinalNumber: (...args: Array<any>) => any;
        era: (...args: Array<any>) => any;
        quarter: (...args: Array<any>) => any;
        month: (...args: Array<any>) => any;
        day: (...args: Array<any>) => any;
        dayPeriod: (...args: Array<any>) => any;
    };
    formatLong?: {
        date: (...args: Array<any>) => any;
        time: (...args: Array<any>) => any;
        dateTime: (...args: Array<any>) => any;
    };
    match?: {
        ordinalNumber: (...args: Array<any>) => any;
        era: (...args: Array<any>) => any;
        quarter: (...args: Array<any>) => any;
        month: (...args: Array<any>) => any;
        day: (...args: Array<any>) => any;
        dayPeriod: (...args: Array<any>) => any;
    };
    options?: {
        weekStartsOn?: 0 | 1 | 2 | 3 | 4 | 5 | 6;
        firstWeekContainsDate?: 1 | 2 | 3 | 4 | 5 | 6 | 7;
    };
}
/**
 * Simple interface for using date-fns with Schedulely
 *
 * Functions can be passed directly from import.
 */
interface DateFnsFunctions {
    addDays: (date: number | Date, amount: number) => Date;
    eachDayOfInterval: (interval: Interval, options?: {
        step?: number | undefined;
    } | undefined) => Date[];
    eachWeekOfInterval: (interval: Interval, options?: {
        locale?: Locale | undefined;
        weekStartsOn?: 0 | 1 | 2 | 3 | 4 | 5 | 6 | undefined;
    } | undefined) => Date[];
    format: (date: number | Date, format: string, options?: {
        locale?: Locale | undefined;
        weekStartsOn?: 0 | 1 | 2 | 3 | 4 | 5 | 6 | undefined;
        firstWeekContainsDate?: number | undefined;
        useAdditionalWeekYearTokens?: boolean | undefined;
        useAdditionalDayOfYearTokens?: boolean | undefined;
    } | undefined) => string;
    startOfMonth: (date: number | Date) => Date;
    startOfWeek: (date: number | Date, options?: {
        locale?: Locale | undefined;
        weekStartsOn?: 0 | 1 | 2 | 3 | 4 | 5 | 6 | undefined;
    } | undefined) => Date;
    addMonths: (date: number | Date, amount: number) => Date;
    isSameWeek(dateLeft: Date | number, dateRight: Date | number, options?: {
        locale?: Locale | undefined;
        weekStartsOn?: 0 | 1 | 2 | 3 | 4 | 5 | 6 | undefined;
    } | undefined): boolean;
}
/**
 * Create a Schedulely compatible DateConvertor from date-fns.
 */
declare const createDateFnsConvertor: (datefns: DateFnsFunctions) => DateTimeAdapter;
/**
 * Create an instance of the default date adapter
 * @param locale Locale override
 * @returns DateTimeAdapter
 */
declare const createDefaultAdapter: (locale?: string) => DateTimeAdapter;
declare const DefaultBackButton: NavigationButtonComponent;
declare const DefaultDay: DayComponent;
declare const DefaultDayHeader: DayHeaderComponent;
/**
 * This component is the header that appears at the top of each day of the week
 * @param param0 Name of the day of the week
 * @returns DayOfWeek component
 */
declare const DefaultDayOfWeek: DayOfWeekComponent;
/**
 * This component is the UI representation of events on the calendar
 * @returns DefaultEvent Component
 */
declare const DefaultEvent: EventComponent;
declare const DefaultForwardButton: NavigationButtonComponent;
declare const DefaultHeaderBanner: HeaderBannerComponent;
declare const DefaultMoreEventsIndicator: MoreEventsIndicatorComponent;
export { Schedulely, ActionState, CalendarState, DateTimeAdapter, DisplaySize, HighlightEventState, CalendarEvent, InternalCalendarEvent, InternalEventWeek, SchedulelyProps, SchedulelyComponents, DayComponentProps, DayComponent, DayHeaderComponentProps, DayHeaderComponent, DayOfWeekProps, DayOfWeekComponent, EventComponentProps, EventComponent, HeaderBannerProps, HeaderBannerComponent, MoreEventsIndicatorProps, MoreEventsIndicatorComponent, NavigationButtonComponentProps, NavigationButtonComponent, createDateFnsConvertor, DateFnsFunctions, createDefaultAdapter, DefaultBackButton, DefaultDay, DefaultDayHeader, DefaultDayOfWeek, DefaultEvent, DefaultForwardButton, DefaultHeaderBanner, DefaultMoreEventsIndicator };
